@@ -510,7 +510,7 @@ def get_certificate_metadata(pem_crt: bytes, *, domain=None) -> OrderedDict:
         metadata["valid"] = False
         logging.debug(f"Certificate ValidationError exception: {e_str}")
         if "all candidates exhausted with no interior errors" in e_str:
-            e_str = "The certificate was not issued by a recognized Mark Verifying Authority (MVA)"
+            e_str = "The certificate was not issued by a recognized Mark Verifying Authority (MVA)."
             validation_errors.append(e_str)
     not_valid_before_timestamp = vmc.not_valid_before_utc.strftime("%Y-%m-%d %H:%M:%SZ")
     not_valid_after_timestamp = vmc.not_valid_after_utc.strftime("%Y-%m-%d %H:%M:%SZ")
@@ -572,7 +572,7 @@ def get_certificate_metadata(pem_crt: bytes, *, domain=None) -> OrderedDict:
                     if required_field not in cert_subject:
                         valid = False
                         validation_errors.append(
-                            f"The the certificate's subject is missing the field {required_field}"
+                            f"The the certificate's subject is missing the required field {required_field}."
                         )
                 for key in FIELD_REQUIRED_IF_FIELD_IS_MISSING:
                     if key in ["All", mark_type]:
@@ -586,7 +586,7 @@ def get_certificate_metadata(pem_crt: bytes, *, domain=None) -> OrderedDict:
                                     ]
                                     if alt_field not in cert_subject:
                                         validation_errors.append(
-                                            f"{alt_field} is required in the certificate subject if {required_field} is not used in the certificate subject"
+                                            f"{alt_field} is required in the certificate subject if {required_field} is not used in the certificate subject."
                                         )
                                         valid = False
                 mark_type_fields = (
@@ -606,7 +606,7 @@ def get_certificate_metadata(pem_crt: bytes, *, domain=None) -> OrderedDict:
                     for field in other_mark_type_fields:
                         if field in cert_subject:
                             validation_errors.append(
-                                f"The subject {field} is used by {other_mark_type} certificates, not {mark_type} certificates"
+                                f"The subject {field} is used by {other_mark_type} certificates, not {mark_type} certificates."
                             )
                             valid = False
             else:
@@ -679,7 +679,7 @@ def _query_bimi_record(
                 unrelated_records.append(record)
 
         if bimi_record_count > 1:
-            raise MultipleBIMIRecords("Multiple BMI records are not permitted")
+            raise MultipleBIMIRecords("Multiple BMI records are not permitted.")
         if len(unrelated_records) > 0:
             ur_str = "\n\n".join(unrelated_records)
             raise UnrelatedTXTRecordFoundAtBIMI(
@@ -702,12 +702,12 @@ def _query_bimi_record(
             for record in records:
                 if record.startswith(txt_prefix):
                     raise BIMIRecordInWrongLocation(
-                        f"The BIMI record must be located at {target}, not {domain}"
+                        f"The BIMI record must be located at {target}, not {domain}."
                     )
         except dns.resolver.NoAnswer:
             pass
         except dns.resolver.NXDOMAIN:
-            raise BIMIRecordNotFound(f"The domain {domain} does not exist")
+            raise BIMIRecordNotFound(f"The domain {domain} does not exist.")
         except Exception as error:
             BIMIRecordNotFound(error)
 
@@ -750,10 +750,11 @@ def query_bimi_record(
         :exc:`checkdmarc.bimi.MultipleBIMIRecords`
 
     """
+    domain = normalize_domain(domain)
     logging.debug(f"Checking for a BIMI record at {selector}._bimi.{domain}")
     warnings = []
     base_domain = get_base_domain(domain)
-    location = domain.lower()
+    location = domain
     record = _query_bimi_record(
         domain,
         selector=selector,
@@ -767,9 +768,9 @@ def query_bimi_record(
         )
         for root_record in root_records:
             if root_record.startswith("v=BIMI1"):
-                warnings.append(f"BIMI record at root of {domain} has no effect")
+                warnings.append(f"BIMI record at root of {domain} has no effect.")
     except dns.resolver.NXDOMAIN:
-        raise BIMIRecordNotFound(f"The domain {domain} does not exist")
+        raise BIMIRecordNotFound(f"The domain {domain} does not exist.")
     except dns.exception.DNSException:
         pass
 
@@ -779,10 +780,16 @@ def query_bimi_record(
         )
         location = base_domain
     if record is None:
-        raise BIMIRecordNotFound(
-            f"A BIMI record does not exist at the {selector} selector for "
-            f"this domain or its base domain"
-        )
+        if domain == base_domain:
+            raise BIMIRecordNotFound(
+                f"A BIMI record does not exist at the {selector} selector for "
+                f"this domain."
+            )
+        else:
+            raise BIMIRecordNotFound(
+                f"A BIMI record does not exist at the {selector} selector for "
+                "this subdomain or its base domain."
+            )
 
     return OrderedDict(
         [("record", record), ("location", location), ("warnings", warnings)]
@@ -845,7 +852,7 @@ def parse_bimi_record(
         "should be; most likely, the _bimi "
         "subdomain record does not actually exist, "
         "and the request for TXT records was "
-        "redirected to the base domain"
+        "redirected to the base domain."
     )
     warnings = []
     record = record.strip('"')
@@ -878,7 +885,7 @@ def parse_bimi_record(
         tag = pair[0].lower().strip()
         tag_value = str(pair[1].strip())
         if tag not in BIMI_TAGS:
-            raise InvalidBIMITag(f"{tag} is not a valid BIMI record tag")
+            raise InvalidBIMITag(f"{tag} is not a valid BIMI record tag.")
         tags[tag] = OrderedDict(value=tag_value)
         if include_tag_descriptions:
             tags[tag]["name"] = BIMI_TAGS[tag]["name"]
@@ -898,7 +905,7 @@ def parse_bimi_record(
                     svg_metadata = get_svg_metadata(raw_xml)
                     if svg_metadata["width"] != svg_metadata["height"]:
                         warnings.append(
-                            f"It is recommended for BIMI SVG dimensions to be square, not {svg_metadata['width']}x{svg_metadata['height']}"
+                            f"It is recommended for BIMI SVG dimensions to be square, not {svg_metadata['width']}x{svg_metadata['height']}."
                         )
                     svg_validation_errors = check_svg_requirements(svg_metadata)
                     if len(svg_validation_errors) > 0:
@@ -919,7 +926,7 @@ def parse_bimi_record(
                         hash_match = True
                     else:
                         warnings.append(
-                            "The image at the l= tag URL does not match the image embedded in the certificate"
+                            "The image at the l= tag URL does not match the image embedded in the certificate."
                         )
             except Exception as e:
                 results["certificate"] = dict(
@@ -933,7 +940,7 @@ def parse_bimi_record(
     if parsed_dmarc_record and not tags["l"] == "":
         if not parsed_dmarc_record["valid"]:
             warnings.append(
-                "The domain does not have a valid DMARC record. A DMARC policy of quarantine or reject must be in place"
+                "The domain does not have a valid DMARC record. A DMARC policy of quarantine or reject must be in place."
             )
         else:
             if parsed_dmarc_record["tags"]["p"]["value"] not in [
@@ -941,23 +948,23 @@ def parse_bimi_record(
                 "reject",
             ]:
                 warnings.append(
-                    "The DMARC policy (p tag) must not be set to quarantine or reject"
+                    "The DMARC policy (p tag) must not be set to quarantine or reject."
                 )
             if parsed_dmarc_record["tags"]["sp"]["value"] not in [
                 "quarantine",
                 "reject",
             ]:
                 warnings.append(
-                    "The DMARC subdomain policy (sp tag) must be set to quarantine or reject if it is used"
+                    "The DMARC subdomain policy (sp tag) must be set to quarantine or reject if it is used."
                 )
             if parsed_dmarc_record["tags"]["pct"]["value"] != 100:
                 warnings.append(
-                    "The DMARC pct tag must be set to 100 (the implicit default) if it is used"
+                    "The DMARC pct tag must be set to 100 (the implicit default) if it is used."
                 )
     matching_certificate_provided = hash_match and cert_metadata["valid"]
     if ("l" in tags and tags["l"]["value"] != "") and not matching_certificate_provided:
         warnings.append(
-            "Most email providers will not display a BIMI image without a valid mark certificate"
+            "Most email providers will not display a BIMI image without a valid mark certificate."
         )
     results["tags"] = tags
     if svg_metadata is not None:
