@@ -339,8 +339,6 @@ def get_mx_hosts(
         )
     if parked and len(hosts) > 0:
         warnings.append("MX records found on parked domains")
-    elif not parked and len(hosts) == 0:
-        warnings.append("No MX records found. Is the domain parked?")
 
     if approved_hostnames:
         approved_hostnames = list(map(lambda h: h.lower(), approved_hostnames))
@@ -382,7 +380,7 @@ def get_mx_hosts(
             if len(tlsa_records) > 0:
                 host["tlsa"] = tlsa_records
             if len(host["addresses"]) == 0:
-                warnings.append(f"{hostname} does not have any A or AAAA DNS records")
+                warnings.append(f"{hostname} does not have any A or AAAA DNS records.")
         except Exception as e:
             if hostname.lower().endswith(".msv1.invalid"):
                 warnings.append(
@@ -428,11 +426,11 @@ def get_mx_hosts(
                 starttls = test_starttls(hostname, cache=STARTTLS_CACHE)
                 tls = starttls
                 if not starttls:
-                    warnings.append(f"STARTTLS is not supported on {hostname}")
+                    warnings.append(f"STARTTLS is not supported on {hostname}.")
                     tls = test_tls(hostname, cache=TLS_CACHE)
 
                     if not tls:
-                        warnings.append(f"SSL/TLS is not supported on {hostname}")
+                        warnings.append(f"SSL/TLS is not supported on {hostname}.")
                 host["tls"] = tls
                 host["starttls"] = starttls
             except DNSException as warning:
